@@ -91,11 +91,11 @@ impl<K: Ord> SearchIndex<K> {
         // settings. Force "use entire string as a keyword" option off:
         let mut keywords: Vec<String> = self.string_keywords(string, false);
 
-        // Pop the last keyword off the list. It's the keyword that we'll be
+        // Pop the last keyword off the list - the keyword that we'll be
         // autocompleting:
         if let Some(last_keyword) = keywords.pop() {
 
-            // Perform search for entire string without the last keyword:
+            // Perform `And` search for entire string without the last keyword:
             let search_results: BTreeSet<&K> =
                 self.internal_search_and(keywords.as_slice());
 
@@ -104,44 +104,25 @@ impl<K: Ord> SearchIndex<K> {
                 self.internal_autocomplete_keyword(&last_keyword);
 
             // Intersect the autocompletions for the last keyword with the
-            // search results. This way, only relevant autocompletions are
-            // returned:
-
-            let autocompletions: Vec<&String> = if search_results.is_empty() {
-
-                autocompletions
-                    .iter()
-                    .take(self.maximum_autocomplete_results)
-                    // `internal_autocomplete_keyword` returns a key-value pair.
-                    // We're autocompleting the key, so discard the value:
-                    .map(|(keyword, _keys)| keyword)
-                    // Copy each keyword from the iterator or we'll get a
-                    // doubly-referenced `&&String` keyword:
-                    .cloned()
-                    // Collect all keyword autocompletions into a `Vec`:
-                    .collect()
-
-            } else {
-
-                autocompletions
-                    .iter()
-                    // Only keep this autocompletion if it contains a key that the
-                    // search results contain:
-                    .filter(|(_keyword, keys)|
-                       keys.iter().any(|key| search_results.contains(key))
-                    ) // filter
-                    // Only return `maximum_autocomplete_results` number of keywords:
-                    .take(self.maximum_autocomplete_results)
-                    // `internal_autocomplete_keyword` returns a key-value pair.
-                    // We're autocompleting the key, so discard the value:
-                    .map(|(keyword, _keys)| keyword)
-                    // Copy each keyword from the iterator or we'll get a
-                    // doubly-referenced `&&String` keyword:
-                    .cloned()
-                    // Collect all keyword autocompletions into a `Vec`:
-                    .collect()
-
-            }; // if
+            // search results for the preceding keywords. This way, only
+            // relevant autocompletions are returned:
+            let autocompletions: Vec<&String> = autocompletions
+                .iter()
+                // Only keep this autocompletion if it contains a key that the
+                // search results contain:
+                .filter(|(_keyword, keys)|
+                   keys.iter().any(|key| search_results.contains(key))
+                ) // filter
+                // Only return `maximum_autocomplete_results` number of keywords:
+                .take(self.maximum_autocomplete_results)
+                // `internal_autocomplete_keyword` returns a key-value pair.
+                // We're autocompleting the key, so discard the value:
+                .map(|(keyword, _keys)| keyword)
+                // Copy each keyword from the iterator or we'll get a
+                // doubly-referenced `&&String` keyword:
+                .cloned()
+                // Collect all keyword autocompletions into a `Vec`:
+                .collect();
 
             // Push a blank placeholder onto the end of the keyword list. We
             // will be putting our autocompletions for the last keyword into
