@@ -1,4 +1,5 @@
 use crate::simple::{AutocompleteType, SearchIndex, SearchType};
+use std::clone::Clone;
 use std::cmp::Ord;
 use std::collections::{BTreeMap, BTreeSet};
 use std::fmt::Debug;
@@ -24,7 +25,7 @@ pub struct SearchIndexBuilder<K> {
 
 // -----------------------------------------------------------------------------
 
-impl<K: Debug + Ord> From<SearchIndex<K>> for SearchIndexBuilder<K> {
+impl<K: Clone + Debug + Ord> From<SearchIndex<K>> for SearchIndexBuilder<K> {
     /// Convert to `SearchIndexBuilder<K>` struct from `SearchIndex<K>` struct.
     fn from(search_index: SearchIndex<K>) -> Self {
         SearchIndexBuilder {
@@ -44,14 +45,14 @@ impl<K: Debug + Ord> From<SearchIndex<K>> for SearchIndexBuilder<K> {
 
 // -----------------------------------------------------------------------------
 
-impl<K: Debug + Ord> From<SearchIndexBuilder<K>> for SearchIndex<K> {
+impl<K: Clone + Debug + Ord> From<&SearchIndexBuilder<K>> for SearchIndex<K> {
     /// Convert to `SearchIndex<K>` struct from `SearchIndexBuilder<K>` struct.
-    fn from(search_index: SearchIndexBuilder<K>) -> Self {
+    fn from(search_index: &SearchIndexBuilder<K>) -> Self {
         SearchIndex {
-            b_tree_map: search_index.b_tree_map,
-            search_type: search_index.search_type,
-            autocomplete_type: search_index.autocomplete_type,
-            split_pattern: search_index.split_pattern,
+            b_tree_map: search_index.b_tree_map.clone(),
+            search_type: search_index.search_type.to_owned(),
+            autocomplete_type: search_index.autocomplete_type.to_owned(),
+            split_pattern: search_index.split_pattern.to_owned(),
             case_sensitive: search_index.case_sensitive,
             minimum_keyword_length: search_index.minimum_keyword_length,
             maximum_keyword_length: search_index.maximum_keyword_length,
@@ -64,73 +65,80 @@ impl<K: Debug + Ord> From<SearchIndexBuilder<K>> for SearchIndex<K> {
 
 // -----------------------------------------------------------------------------
 
-impl<K: Debug + Ord> SearchIndexBuilder<K> {
+impl<K: Clone + Debug + Ord> SearchIndexBuilder<K> {
 
     /// Initialize `SearchIndexBuilder` with default settings.
-    pub fn default() -> SearchIndexBuilder<K> {
+    pub fn default() -> Self {
         SearchIndexBuilder::from(SearchIndex::default())
     } // fn
 
-    /// Logical conjuction for connecting search results for each keyword.
-    pub fn search_type(&mut self, search_type: &SearchType) -> &mut SearchIndexBuilder<K> {
+    /// Search type (or logical conjuction). Used to determine how to connect
+    /// search results for each keyword. See [`SearchType`] for more
+    /// information.
+    ///
+    /// [`SearchType`]: enum.SearchType.html
+    pub fn search_type(&mut self, search_type: &SearchType) -> &mut Self {
         self.search_type = search_type.to_owned();
         self
     } // fn
 
-    /// Logical conjuction for connecting autcompletion results for each
-    /// keyword.
-    pub fn autocomplete_type(&mut self, autocomplete_type: &AutocompleteType) -> &mut SearchIndexBuilder<K> {
+    /// Autocomplete type (or keyword scope). Used to determine if or how to
+    /// filtering keyword results for autocompletion. See [`AutocompleteType`]
+    /// for more information.
+    ///
+    /// [`AutocompleteType`]: enum.AutocompleteType.html
+    pub fn autocomplete_type(&mut self, autocomplete_type: &AutocompleteType) -> &mut Self {
         self.autocomplete_type = autocomplete_type.to_owned();
         self
     } // fn
 
     /// Characters used to split strings into keywords.
-    pub fn split_pattern(&mut self, split_pattern: &Option<Vec<char>>) -> &mut SearchIndexBuilder<K> {
+    pub fn split_pattern(&mut self, split_pattern: &Option<Vec<char>>) -> &mut Self {
         self.split_pattern = split_pattern.to_owned();
         self
     } // fn
 
     /// Indicates whether the search index is case sensitive or not. If set to
     /// false (case insensitive), all keywords will be normalized to lower case.
-    pub fn case_sensitive(&mut self, case_sensitive: &bool) -> &mut SearchIndexBuilder<K> {
+    pub fn case_sensitive(&mut self, case_sensitive: &bool) -> &mut Self {
         self.case_sensitive = *case_sensitive;
         self
     } // fn
 
     /// Minimum keyword length (in chars or codepoints) to be indexed.
-    pub fn min_keyword_len(&mut self, minimum_keyword_length: &usize) -> &mut SearchIndexBuilder<K> {
+    pub fn min_keyword_len(&mut self, minimum_keyword_length: &usize) -> &mut Self {
         self.minimum_keyword_length = *minimum_keyword_length;
         self
     } // fn
 
     /// Maximum keyword length (in chars or codepoints) to be indexed.
-    pub fn max_keyword_len(&mut self, maximum_keyword_length: &usize) -> &mut SearchIndexBuilder<K> {
+    pub fn max_keyword_len(&mut self, maximum_keyword_length: &usize) -> &mut Self {
         self.maximum_keyword_length = *maximum_keyword_length;
         self
     } // fn
 
     /// Maximum string length (in chars or codepoints) to be indexed. If set,
-    /// Indicium will index the record's full field text / whole strings as a
-    /// single keyword for autocompletion purposes.
-    pub fn max_string_len(&mut self, maximum_string_length: &Option<usize>) -> &mut SearchIndexBuilder<K> {
+    /// Indicium will index the record's _full field text_ & _whole strings_ as
+    /// a single keyword for autocompletion purposes.
+    pub fn max_string_len(&mut self, maximum_string_length: &Option<usize>) -> &mut Self {
         self.maximum_string_length = *maximum_string_length;
         self
     } // fn
 
     /// Maximum number of auto-complete options to return.
-    pub fn max_autocomplete_results(&mut self, maximum_autocomplete_results: &usize) -> &mut SearchIndexBuilder<K> {
+    pub fn max_autocomplete_results(&mut self, maximum_autocomplete_results: &usize) -> &mut Self {
         self.maximum_autocomplete_results = *maximum_autocomplete_results;
         self
     } // fn
 
     /// Maximum number of search results to return.
-    pub fn max_search_results(&mut self, maximum_search_results: &usize) -> &mut SearchIndexBuilder<K> {
+    pub fn max_search_results(&mut self, maximum_search_results: &usize) -> &mut Self {
         self.maximum_search_results = *maximum_search_results;
         self
     } // fn
 
     /// Build `SearchIndex` from the settings given to the `SearchIndexBuilder`.
-    pub fn build(self) -> SearchIndex<K> {
+    pub fn build(&self) -> SearchIndex<K> {
         SearchIndex::from(self)
     } // fn
 
